@@ -1,19 +1,17 @@
-//
-// Sysinfo
-//
-// Copyright (c) 2020 Guillaume Gomez
-//
+// Take a look at the license at the top of the repository in the LICENSE file.
 
-// This test is used to ensure that the processors are loaded whatever the method
-// used to initialize `System`.
+// This test is used to ensure that the processors are not loaded by default.
 
 #[test]
 fn test_processor() {
     use sysinfo::{ProcessorExt, SystemExt};
 
     if sysinfo::System::IS_SUPPORTED {
-        let s = sysinfo::System::new();
+        let mut s = sysinfo::System::new();
+        assert!(s.processors().is_empty());
+        s.refresh_cpu();
         assert!(!s.processors().is_empty());
+
         let s = sysinfo::System::new_all();
         assert!(!s.processors().is_empty());
 
